[llvm] 073aebc - [Utils] Improved chunk-print-before-all.py script
via llvm-commits
llvm-commits at lists.llvm.org
Tue Nov 22 10:12:26 PST 2022
Author: dbakunevich
Date: 2022-11-23T01:11:54+07:00
New Revision: 073aebc431d55d895f84d84f61cd6a1a358a4d2f
URL: https://github.com/llvm/llvm-project/commit/073aebc431d55d895f84d84f61cd6a1a358a4d2f
DIFF: https://github.com/llvm/llvm-project/commit/073aebc431d55d895f84d84f61cd6a1a358a4d2f.diff
LOG: [Utils] Improved chunk-print-before-all.py script
As part of this patch, the ability to work with dump files
containing ir after passes received using the -print-after-all
option was added to script chunk-print-before-all.py.
The names of the output files have also been changed.
Before: chunk-NUM.ll
Now: NUM-STAGE-PASS_NAME.ll
NUM - sequence number of the pass operation.
STAGE - stage of the pass operation (for example: before, after, dump).
PASS_NAME - the name of the pass.
Added:
Modified:
llvm/utils/chunk-print-before-all.py
Removed:
################################################################################
diff --git a/llvm/utils/chunk-print-before-all.py b/llvm/utils/chunk-print-before-all.py
index d17bae85cdd32..75c3a690d0a8f 100755
--- a/llvm/utils/chunk-print-before-all.py
+++ b/llvm/utils/chunk-print-before-all.py
@@ -1,21 +1,24 @@
#!/usr/bin/env python
-# Given a -print-before-all -print-module-scope log from an opt invocation,
-# chunk it into a series of individual IR files, one for each pass invocation.
-# If the log ends with an obvious stack trace, try to split off a separate
-# "crashinfo.txt" file leaving only the valid input IR in the last chunk.
-# Files are written to current working directory.
-from __future__ import print_function
+# Given a -print-before-all and/or -print-after-all -print-module-scope log from
+# an opt invocation, chunk it into a series of individual IR files, one for each
+# pass invocation. If the log ends with an obvious stack trace, try to split off
+# a separate "crashinfo.txt" file leaving only the valid input IR in the last
+# chunk. Files are written to current working directory.
import sys
-basename = "chunk-"
chunk_id = 0
-def print_chunk(lines):
+# This function gets the pass name from the following line:
+# *** IR Dump Before/After PASS_NAME... ***
+def get_pass_name(line, prefix):
+ short_line = line[line.find(prefix) + len(prefix) + 1:]
+ return re.split(' |<', short_line)[0]
+
+def print_chunk(lines, prefix, pass_name):
global chunk_id
- global basename
- fname = basename + str(chunk_id) + ".ll"
+ fname = str(chunk_id) + "-" + prefix + "-" + pass_name + ".ll"
chunk_id = chunk_id + 1
print("writing chunk " + fname + " (" + str(len(lines)) + " lines)")
with open(fname, "w") as f:
@@ -26,11 +29,18 @@ def print_chunk(lines):
for line in sys.stdin:
if line.startswith("*** IR Dump Before "):
if len(cur) != 0:
- print_chunk(cur);
+ print_chunk(cur, "before", pass_name)
+ cur = []
+ cur.append("; " + line)
+ pass_name = get_pass_name(line, "Before")
+ elif line.startswith("*** IR Dump After "):
+ if len(cur) != 0:
+ print_chunk(cur, "after", pass_name)
cur = []
cur.append("; " + line)
+ pass_name = get_pass_name(line, "After")
elif line.startswith("Stack dump:"):
- print_chunk(cur);
+ print_chunk(cur, "crash", pass_name)
cur = []
cur.append(line)
is_dump = True
@@ -42,4 +52,4 @@ def print_chunk(lines):
with open("crashinfo.txt", "w") as f:
f.writelines(cur)
else:
- print_chunk(cur);
+ print_chunk(cur, "last", pass_name)
More information about the llvm-commits
mailing list